@@ -62,7 +62,7 @@ struct _MiaGLVolume {
 	gfloat sx, sy, sz; 
 	gfloat *pixels;
 
-	GMutex *pixel_mutex; 
+	GMutex pixel_mutex; 
 };
 
 static GObject *__mia_glvolume_constructor (GType type,
@@ -160,10 +160,10 @@ MiaVector3d *mia_glvolume_set_volume(MiaGLVolume *self, MiaImage3d *image)
 	/*pending  = mia_image3d_crop_pow2(image, max_texture_size);*/
 
 	/* reuse possibly allocated image */
-	g_mutex_lock(self->pixel_mutex);
+	g_mutex_lock(&self->pixel_mutex);
 	pixels = self->pixels; 
 	self->pixels = NULL; 
-	g_mutex_unlock(self->pixel_mutex);
+	g_mutex_unlock(&self->pixel_mutex);
 
 	
 	if (!pixels)
@@ -215,9 +215,9 @@ MiaVector3d *mia_glvolume_set_volume(MiaGLVolume *self, MiaImage3d *image)
 	g_object_unref(pending);
 	
 	/* Data copied, make it available */
-	g_mutex_lock(self->pixel_mutex);
+	g_mutex_lock(&self->pixel_mutex);
 	self->pixels = pixels; 
-	g_mutex_unlock(self->pixel_mutex);
+	g_mutex_unlock(&self->pixel_mutex);
 	
 	g_message("Center @ %f %f %f", self->sx, self->sy, self->sz);
 	return mia_vector3d_new(self->sx, self->sy, self->sz); 
@@ -290,7 +290,7 @@ __mia_glvolume_instance_init (GTypeInstance * instance, gpointer UNUSED(g_class)
 	MiaGLVolume *self = (MiaGLVolume *) instance;
 	self->dispose_has_run = FALSE;
 	self->pixels = NULL; 
-	self->pixel_mutex = g_mutex_new();
+	g_mutex_init(&self->pixel_mutex);
 	drawable->is_transparent = FALSE; 
 }
 
@@ -354,7 +354,6 @@ __mia_glvolume_finalize (GObject * obj)
 	/* add your destruction code here */
 	if (self->pixels)
 		g_free(self->pixels);
-	g_mutex_free(self->pixel_mutex);
 	
 
 	/* chain up to the parent class */
@@ -454,7 +453,7 @@ __gl_attach (MiaGLDrawable * obj)
 		return; 
 	}
 
-	g_mutex_lock(self->pixel_mutex);
+	g_mutex_lock(&self->pixel_mutex);
 	if (self->pixels)
 		__mia_glvolume_set_volume(self);
 
@@ -519,7 +518,7 @@ __gl_attach (MiaGLDrawable * obj)
 		g_warning ("get 'alpha_discard': error %s", gluErrorString (error));
 
 
-	g_mutex_unlock(self->pixel_mutex);	
+	g_mutex_unlock(&self->pixel_mutex);	
 
 	obj->is_attached = TRUE;
 	obj->is_visible = TRUE;
@@ -768,10 +767,10 @@ __initialize(MiaGLDrawable *obj)
 	MiaGLVolume *self = MIA_GLVOLUME (obj);
 	if (!obj->is_attached)
 		return;
-	g_mutex_lock(self->pixel_mutex);
+	g_mutex_lock(&self->pixel_mutex);
 	if (self->pixels)
 		__mia_glvolume_set_volume(self);
-	g_mutex_unlock(self->pixel_mutex);
+	g_mutex_unlock(&self->pixel_mutex);
 }
 
 
